;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "transient" "0.13.2"
  "Transient commands."
  '((emacs    "28.1")
    (compat   "30.1")
    (cond-let "1.0")
    (seq      "2.24"))
  :url "https://github.com/magit/transient"
  :commit "43cbef8539e3c7398d0280958b42f94dac7ea7b4"
  :revdesc "v0.13.2-0-g43cbef8539e3"
  :keywords '("extensions")
  :authors '(("Jonas Bernoulli" . "emacs.transient@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.transient@jonas.bernoulli.dev")))
